@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,31 +17,29 @@ GravatarDownloadPixmapWidgetTest::GravatarDownloadPixmapWidgetTest(QObject *pare
 {
 }
 
-GravatarDownloadPixmapWidgetTest::~GravatarDownloadPixmapWidgetTest()
-{
-}
+GravatarDownloadPixmapWidgetTest::~GravatarDownloadPixmapWidgetTest() = default;
 
 void GravatarDownloadPixmapWidgetTest::shouldHaveDefaultValue()
 {
     Gravatar::GravatarDownloadPixmapWidget w;
-    auto *lab = w.findChild<QLabel *>(QStringLiteral("labemail"));
+    auto lab = w.findChild<QLabel *>(QStringLiteral("labemail"));
     QVERIFY(lab);
 
-    auto *lineEdit = w.findChild<QLineEdit *>(QStringLiteral("email"));
+    auto lineEdit = w.findChild<QLineEdit *>(QStringLiteral("email"));
     QVERIFY(lineEdit);
 
-    auto *getPixmapButton = w.findChild<QPushButton *>(QStringLiteral("searchbutton"));
+    auto getPixmapButton = w.findChild<QPushButton *>(QStringLiteral("searchbutton"));
     QVERIFY(getPixmapButton);
     QVERIFY(!getPixmapButton->isEnabled());
 
-    auto *resultLabel = w.findChild<QLabel *>(QStringLiteral("resultlabel"));
+    auto resultLabel = w.findChild<QLabel *>(QStringLiteral("resultlabel"));
     QVERIFY(resultLabel);
 
-    auto *useLibravatar = w.findChild<QCheckBox *>(QStringLiteral("uselibravatar"));
+    auto useLibravatar = w.findChild<QCheckBox *>(QStringLiteral("uselibravatar"));
     QVERIFY(useLibravatar);
     QVERIFY(!useLibravatar->isChecked());
 
-    auto *fallBackGravatar = w.findChild<QCheckBox *>(QStringLiteral("fallbackgravatar"));
+    auto fallBackGravatar = w.findChild<QCheckBox *>(QStringLiteral("fallbackgravatar"));
     QVERIFY(fallBackGravatar);
     QVERIFY(!fallBackGravatar->isChecked());
 }
@@ -49,9 +47,9 @@ void GravatarDownloadPixmapWidgetTest::shouldHaveDefaultValue()
 void GravatarDownloadPixmapWidgetTest::shouldChangeButtonEnableState()
 {
     Gravatar::GravatarDownloadPixmapWidget w;
-    auto *lineEdit = w.findChild<QLineEdit *>(QStringLiteral("email"));
+    auto lineEdit = w.findChild<QLineEdit *>(QStringLiteral("email"));
 
-    auto *getPixmapButton = w.findChild<QPushButton *>(QStringLiteral("searchbutton"));
+    auto getPixmapButton = w.findChild<QPushButton *>(QStringLiteral("searchbutton"));
     QVERIFY(!getPixmapButton->isEnabled());
 
     lineEdit->setText(QStringLiteral("foo"));
